@@ -1,5 +1,7 @@
+# frozen_string_literal: true
 require 'sprockets/autoload'
 require 'sprockets/digest_utils'
+require 'sprockets/source_map_utils'
 
 module Sprockets
   # Public: Uglifier/Uglify compressor.
@@ -15,7 +17,7 @@ module Sprockets
   #       Sprockets::UglifierCompressor.new(comments: :copyright)
   #
   class UglifierCompressor
-    VERSION = '1'
+    VERSION = '3'
 
     # Public: Return singleton instance with default options.
     #
@@ -35,22 +37,30 @@ module Sprockets
     attr_reader :cache_key
 
     def initialize(options = {})
-      # Feature detect Uglifier 2.0 option support
-      if Autoload::Uglifier::DEFAULTS[:copyright]
-        # Uglifier < 2.x
-        options[:copyright] ||= false
-      else
-        # Uglifier >= 2.x
-        options[:comments] ||= :none
-      end
+      options[:comments] ||= :none
 
       @options = options
       @cache_key = "#{self.class.name}:#{Autoload::Uglifier::VERSION}:#{VERSION}:#{DigestUtils.digest(options)}".freeze
     end
 
     def call(input)
-      @uglifier ||= Autoload::Uglifier.new(@options)
-      @uglifier.compile(input[:data])
+      case Autoload::Uglifier::VERSION.to_i
+      when 1
+        raise "uglifier 1.x is no longer supported, please upgrade to 2.x or newer"
+      when 2
+        input_options = { source_filename: input[:filename] }
+      else
+        input_options = { source_map: { filename: input[:filename] } }
+      end
+
+      uglifier = Autoload::Uglifier.new(@options.merge(input_options))
+
+      js, map = uglifier.compile_with_map(input[:data])
+
+      map = SourceMapUtils.format_source_map(JSON.parse(map), input)
+      map = SourceMapUtils.combine_source_maps(input[:metadata][:map], map)
+
+      { data: js, map: map }
     end
   end
 end
