@@ -2,7 +2,7 @@
 require 'minitest/autorun'
 require 'sprockets/path_utils'
 
-class TestPathUtils < MiniTest::Test
+class TestPathUtils < Minitest::Test
   include Sprockets::PathUtils
 
   DOSISH = File::ALT_SEPARATOR != nil
@@ -109,6 +109,8 @@ class TestPathUtils < MiniTest::Test
     subpath = File.expand_path("../fixtures/default/app/application.js", __FILE__)
     assert_equal "app/application.js", split_subpath(path, subpath)
 
+    assert_nil split_subpath(path, nil)
+
     subpath = File.expand_path("../fixtures/default", __FILE__)
     assert_equal "", split_subpath(path, subpath)
 
