@@ -2,7 +2,7 @@
 require 'minitest/autorun'
 require 'sprockets/utils'
 
-class TestUtils < MiniTest::Test
+class TestUtils < Minitest::Test
   include Sprockets::Utils
 
   def test_duplicable
